//******************************************************************************
// FILE:       	lcd_wiring_es449.h
//              
// AUTHOR:     	CC Cox - SynchroSystems
//              
// PROJECT:    	SynchroChron
//              
// DESCRIPTION:	LCD wiring configuration header file
//				Configured for modified Softbaugh ES449 board
//					Remove original 48 pin LCD (labeled LCD1)
//					Install 44 pin SynchroChron LCD in leftmost holes of LCD1 (1-22, 27-44)
//					Jumper J23: 2-3, 5-6, 8-9, 16-17
//					Jumper LCD1: 23-39, 24-38
//
// CUSTOMIZATION:	Make a copy of this file and rename it appropriately.
//					Modify the new file to reflect the new wiring configuration.
//					Modify lcd.c to include the new file instead of this file.
//
// HISTORY:
//		$Log: lcd_wiring_es449.h,v $
//		Revision 1.5  2006-10-02 15:46:53-04  chuck
//		<>
//
//		Revision 1.3 2006-01-13 chuck
//		Code review changes
//
//		Revision 1.2 2006-01-12 chuck
//		Code review release
//
//		Revision 1.0 2005-03-13 chuck
//		Initial revision
//
// Copyright (c) 2006 SynchroSystems Inc
//******************************************************************************
#ifndef __LCD_WIRING_ES449_H
#define __LCD_WIRING_ES449_H

//==============================================================================
// PRIVATE DECLARATIONS
//==============================================================================

//------------------------------------------------------------------------------
// ROM data
//------------------------------------------------------------------------------

//------------------------------------------------------------------------------
//
// These tables describe how the LCD common and segment pins are 
// connected to the MCU LCD controller pins
//
// The symbolic names (i.e. "S0") refer to the LCD pin labels.
// The numeric values (as defined by the enum) refer to MCU pin labels.
//
// In the following example, LCD COM2 (pin 43) is wired to MCU COM0 (pin 52),
// LCD COM0 (pin 41) is wired to MCU COM1 (pin 53), and so forth.
// 
// enum
// {
// 	// MCU COM0 (pin 52)
// 	C2 = 0,						// LCD COM2 (pin 43)
// 	C0,							// LCD COM0 (pin 41)
// 	C3,							// LCD COM3 (pin 44)
// 	C1							// LCD COM1 (pin 42)
// };
//
//------------------------------------------------------------------------------

//
// common pin wiring
// symbolic names refer to LCD pin labels
// numeric values refer to MCU pin labels
//
enum
{
	// MCU COM0 (pin 52)
	C0 = 0,						// LCD COM0 (pin 41)
	C1,							// LCD COM1 (pin 42)
	C2,							// LCD COM2 (pin 43)
	C3							// LCD COM3 (pin 44)
};

//
// segment pin wiring
//
enum
{
	// MCU S0 (pin 12)
	S33 = 0,					// LCD S33 (pin 34)
	S37,						// LCD S37 (pin 38)
	S31,						// LCD S31 (pin 32)
	S30,						// LCD S30 (pin 31)
	S22,						// LCD S22 (pin 23)
	// MCU S5 (pin 17)
	S23,						// LCD S23 (pin 24)
	S24,						// LCD S24 (pin 25)
	S25,						// LCD S25 (pin 26)
	S26,						// LCD S26 (pin 27)
	S27,						// LCD S27 (pin 28)
	// MCU S10 (pin 22)
	S28,						// LCD S28 (pin 29)
	S29,						// LCD S29 (pin 30)
	S32,						// LCD S32 (pin 33)
	S35,						// LCD S35 (pin 36)
	S36,						// LCD S36 (pin 37)
	// MCU S15 (pin 27)
	S34,						// LCD S34 (pin 35)
	S21,						// LCD S21 (pin 22)
	S20,						// LCD S20 (pin 21)
	S19,						// LCD S19 (pin 20)
	S18,						// LCD S18 (pin 19)
	// MCU S20 (pin 32)
	S17,						// LCD S17 (pin 18)
	S16,						// LCD S16 (pin 17)
	S15,						// LCD S15 (pin 16)
	S14,						// LCD S14 (pin 15)
	S13,						// LCD S13 (pin 14)
	// MCU S25 (pin 37)
	S12,						// LCD S12 (pin 13)
	S11,						// LCD S11 (pin 12)
	S10,						// LCD S10 (pin 11)
	S09,						// LCD S9  (pin 10)
	S08,						// LCD S8  (pin  9)
	// MCU S30 (pin 42)
	S07,						// LCD S7  (pin  8)
	S06,						// LCD S6  (pin  7)
	S05,						// LCD S5  (pin  6)
	S04,						// LCD S4  (pin  5)
	S03,						// LCD S3  (pin  4)
	// MCU S35 (pin 47)
	S02,						// LCD S2  (pin  3)
	S01,						// LCD S1  (pin  2)
	S00,						// LCD S0  (pin  1)
	S39,						// LCD S39 (pin 40)
	S38							// LCD S38 (pin 39)
};

#endif	// __LCD_WIRING_ES449_H 
